Rename FoldedGraph -> DSInfo to be consistent with other passes
delete some dead methods


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@17410 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Analysis/DataStructure/EquivClassGraphs.cpp b/lib/Analysis/DataStructure/EquivClassGraphs.cpp
index 1d80b9c..70c8f6b 100644
--- a/lib/Analysis/DataStructure/EquivClassGraphs.cpp
+++ b/lib/Analysis/DataStructure/EquivClassGraphs.cpp
@@ -210,7 +210,7 @@
       for (std::set<Function*>::const_iterator EqI = EqClass.begin(),
              EqEnd = EqClass.end(); EqI != EqEnd; ++EqI) {
         Function* F = *EqI;
-        DSGraph*& FG = FoldedGraphsMap[F];
+        DSGraph*& FG = DSInfo[F];
 
         if (F == LF || FG == mergedG)
           continue;
@@ -253,7 +253,7 @@
 
 DSGraph &PA::EquivClassGraphs::getOrCreateGraph(Function &F) {
   // Has the graph already been created?
-  DSGraph *&Graph = FoldedGraphsMap[&F];
+  DSGraph *&Graph = DSInfo[&F];
   if (Graph) return *Graph;
 
   DSGraph &CBUGraph = CBU->getDSGraph(F);
@@ -263,11 +263,11 @@
   Graph->setGlobalsGraph(&getGlobalsGraph());
   Graph->setPrintAuxCalls();
 
   // Make sure to update the FoldedGraphsMap map for all functions in the graph!
   for (DSGraph::ReturnNodesTy::iterator I = Graph->getReturnNodes().begin();
        I != Graph->getReturnNodes().end(); ++I)
     if (I->first != &F) {
-      DSGraph*& FG = FoldedGraphsMap[I->first];
+      DSGraph *&FG = DSInfo[I->first];
       assert(FG == NULL || FG == &CBU->getDSGraph(*I->first) &&
              "Merging function in SCC twice?");
       FG = Graph;
@@ -263,11 +263,11 @@
   Graph->setPrintAuxCalls();
 
-  // Make sure to update the FoldedGraphsMap map for all functions in the graph!
+  // Make sure to update the DSInfo map for all functions in the graph!
   for (DSGraph::ReturnNodesTy::iterator I = Graph->getReturnNodes().begin();
        I != Graph->getReturnNodes().end(); ++I)